@@ -61,7 +61,7 @@
 #'
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' ## Example of estimating TDFs for a simple system with known dietary proportions
 #'
 #' # Data set 1: 10 obs on 2 isos, 4 sources, with tefs and concdep
@@ -70,34 +70,34 @@
 #' # The data
 #' data(simmr_data_1)
 #' # Load into simmr
-# simmr_tdf <- with(
-#   simmr_data_1,
-#   simmr_load(
-#     mixtures = mixtures,
-#     source_names = source_names,
-#     source_means = source_means,
-#     source_sds = source_sds,
-#     correction_means = correction_means,
-#     correction_sds = correction_sds,
-#     concentration_means = concentration_means
-#   )
-# )
+#' simmr_tdf <- with(
+#'   simmr_data_1,
+#'   simmr_load(
+#'     mixtures = mixtures,
+#'     source_names = source_names,
+#'     source_means = source_means,
+#'     source_sds = source_sds,
+#'     correction_means = correction_means,
+#'     correction_sds = correction_sds,
+#'     concentration_means = concentration_means
+#'   )
+#' )
 #'
 #' # Plot
 #' plot(simmr_tdf)
 #'
 #' # MCMC run
-# simmr_tdf_out <- simmr_mcmc_tdf(simmr_tdf,
-#   p = matrix(
-#     rep(
-#       1 / simmr_tdf$n_sources,
-#       simmr_tdf$n_sources
-#     ),
-#     ncol = simmr_tdf$n_sources,
-#     nrow = simmr_tdf$n_obs,
-#     byrow = TRUE
-#   )
-# )
+#' simmr_tdf_out <- simmr_mcmc_tdf(simmr_tdf,
+#'   p = matrix(
+#'     rep(
+#'       1 / simmr_tdf$n_sources,
+#'       simmr_tdf$n_sources
+#'     ),
+#'     ncol = simmr_tdf$n_sources,
+#'     nrow = simmr_tdf$n_obs,
+#'     byrow = TRUE
+#'   )
+#' )
 
 #' # Summary
 #' summary(simmr_tdf_out, type = "diagnostics")
@@ -105,18 +105,18 @@
 #'
 #' # Now put these corrections back into the model and check the
 #' # iso-space plots and dietary output
-# simmr_tdf_2 <- with(
-#   simmr_data_1,
-#   simmr_load(
-#     mixtures = mixtures,
-#     source_names = source_names,
-#     source_means = source_means,
-#     source_sds = source_sds,
-#     correction_means = simmr_tdf_out$c_mean_est,
-#     correction_sds = simmr_tdf_out$c_sd_est,
-#     concentration_means = concentration_means
-#   )
-# )
+#' simmr_tdf_2 <- with(
+#'   simmr_data_1,
+#'   simmr_load(
+#'     mixtures = mixtures,
+#'     source_names = source_names,
+#'     source_means = source_means,
+#'     source_sds = source_sds,
+#'     correction_means = simmr_tdf_out$c_mean_est,
+#'     correction_sds = simmr_tdf_out$c_sd_est,
+#'     concentration_means = concentration_means
+#'   )
+#' )
 #'
 #' # Plot with corrections now
 #' plot(simmr_tdf_2)
@@ -189,33 +189,7 @@ simmr_mcmc_tdf.simmr_input <- function(simmr_in,
   if (min(table(simmr_in$group)) > 1 & min(table(simmr_in$group)) < 4) warning("At least 1 group has less than 4 observations - either put each observation in an individual group or use informative prior information")
 
   # Set up the model string
-  model_string <- "
-model {
-  # Likelihood
-  for (j in 1:J) {
-    for (i in 1:N) {
-      y[i,j] ~ dnorm(inprod(p[i,]*q[,j], s_mean[,j]+c_mean[,j]) / inprod(p[i,],q[,j]), 1/var_y[i,j])
-      var_y[i,j] <- inprod(pow(p[i,]*q[,j],2),pow(s_sd[,j],2)+pow(c_sd[,j],2))/pow(inprod(p[i,],q[,j]),2)
-+ pow(sigma[j],2)
-    }
-
-  }
-
-  # Prior on sigma
-  for(j in 1:J) { sigma[j] ~ dgamma(0.001, sig_upp) }
-
-  # Priors on c
-  for (j in 1:J) {
-    for (k in 1:K) {
-      c_mean[k,j] <- c_mean_j[j]
-      c_sd[k,j] <- c_sd_j[j]
-    }
-    c_mean_j[j] ~ dgamma(c_mean_est[j], 1)
-    c_sd_j[j] ~ dgamma(c_sd_est[j], 1)
-  }
-
-}
-"
+  jags_file <- system.file("jags_models", "mcmc_tdf.jags", package = "simmr")
 
   if (simmr_in$n_groups > 1) stop("TDF calculation currently only works for single group data")
 
@@ -225,7 +199,7 @@ model {
 
   # Determine if a single observation or not
   if (nrow(curr_mix) == 1) {
-    cat("Only 1 mixture value, performing a simmr solo run...\n")
+    message("Only 1 mixture value, performing a simmr solo run...\n")
     solo <- TRUE
   } else {
     solo <- FALSE
@@ -250,7 +224,7 @@ model {
   output <- R2jags::jags(
     data = data,
     parameters.to.save = c("c_mean", "c_sd"),
-    model.file = textConnection(model_string),
+    model.file = jags_file,
     n.chains = mcmc_control$n.chain,
     n.iter = mcmc_control$iter,
     n.burnin = mcmc_control$burn,
